==> sway-parse-0.12.1.crate: sway-parse-0.12.1/src/priv_prelude.rs <==
pub use {
    crate::{
        assignable::Assignable,
        brackets::{AngleBrackets, Braces, Parens, SquareBrackets},
        dependency::Dependency,
        error::{ParseError, ParseErrorKind},
        expr::{
            asm::{AsmBlock, AsmImmediate},
            op_code::{parse_instruction, Instruction},
            CodeBlockContents, Expr,
        },
        generics::{GenericArgs, GenericParams},
        item::{
            item_abi::ItemAbi,
            item_const::ItemConst,
            item_enum::ItemEnum,
            item_fn::ItemFn,
            item_impl::ItemImpl,
            item_storage::ItemStorage,
            item_struct::ItemStruct,
            item_trait::{ItemTrait, Traits},
            item_use::ItemUse,
            FnSignature, Item, TypeField,
        },
        keywords::*,
        literal::{LitChar, LitInt, LitIntType, LitString, Literal},
        parse::{Parse, ParseToEnd, Peek},
        parser::{ErrorEmitted, ParseResult, Parser, ParserConsumed, Peeker},
        path::{PathExpr, PathType},
        pattern::Pattern,
        punctuated::Punctuated,
        statement::{Statement, StatementLet},
        token::{Delimiter, Group, Punct, PunctKind, Spacing, TokenStream, TokenTree},
        ty::Ty,
        where_clause::{WhereBound, WhereClause},
    },
    extension_trait::extension_trait,
    num_bigint::BigUint,
    std::{
        fmt, marker::PhantomData, mem, ops::ControlFlow, path::PathBuf, str::FromStr, sync::Arc,
    },
    sway_types::{Ident, Span},
    thiserror::Error,
    unicode_xid::UnicodeXID,
};

==> sway-parse-0.12.2.crate: sway-parse-0.12.2/src/priv_prelude.rs <==
pub use {
    crate::{
        assignable::Assignable,
        attribute::{Attribute, AttributeDecl},
        brackets::{AngleBrackets, Braces, Parens, SquareBrackets},
        dependency::Dependency,
        error::{ParseError, ParseErrorKind},
        expr::{
            asm::{AsmBlock, AsmImmediate},
            op_code::{parse_instruction, Instruction},
            CodeBlockContents, Expr,
        },
        generics::{GenericArgs, GenericParams},
        item::{
            item_abi::ItemAbi,
            item_const::ItemConst,
            item_enum::ItemEnum,
            item_fn::ItemFn,
            item_impl::ItemImpl,
            item_storage::ItemStorage,
            item_struct::ItemStruct,
            item_trait::{ItemTrait, Traits},
            item_use::ItemUse,
            FnSignature, Item, ItemKind, TypeField,
        },
        keywords::*,
        literal::{LitChar, LitInt, LitIntType, LitString, Literal},
        parse::{Parse, ParseToEnd, Peek},
        parser::{ErrorEmitted, ParseResult, Parser, ParserConsumed, Peeker},
        path::{PathExpr, PathType},
        pattern::Pattern,
        punctuated::Punctuated,
        statement::{Statement, StatementLet},
        token::{Delimiter, Group, Punct, PunctKind, Spacing, TokenStream, TokenTree},
        ty::Ty,
        where_clause::{WhereBound, WhereClause},
    },
    extension_trait::extension_trait,
    num_bigint::BigUint,
    std::{
        fmt, marker::PhantomData, mem, ops::ControlFlow, path::PathBuf, str::FromStr, sync::Arc,
    },
    sway_types::{Ident, Span},
    thiserror::Error,
    unicode_xid::UnicodeXID,
};
